pub trait TermReadEventsAndRaw {
// Required method
fn events_and_raw(self) -> EventsAndRaw<Self> ⓘ
where Self: Sized;
}Expand description
Extension to TermRead trait. A separate trait in order to maintain backwards compatibility.
Required Methods
Sourcefn events_and_raw(self) -> EventsAndRaw<Self> ⓘwhere
Self: Sized,
fn events_and_raw(self) -> EventsAndRaw<Self> ⓘwhere
Self: Sized,
An iterator over input events and the bytes that define them.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".