IntoAlternateScreen

Trait IntoAlternateScreen 

pub trait IntoAlternateScreen: Write + Sized {
    // Provided method
    fn into_alternate_screen(self) -> Result<AlternateScreen<Self>> { ... }
}
Extension trait for writers, providing the into_alternate_screen function.

Provided Methods

fn into_alternate_screen(self) -> Result<AlternateScreen<Self>>

Switch the terminal controlled by this writer to use the alternate screen. The terminal will be restored to the main screen when the AlternateScreen returned by this function is dropped.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors